@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -8,12 +8,15 @@
 #include "AudioInput.h"
 #include "AudioOutput.h"
 #include "AudioOutputSample.h"
+#include "AudioOutputToken.h"
 #include "NetworkConfig.h"
 #include "Utils.h"
 #include "Global.h"
 
 #include <QSignalBlocker>
 
+#include <cstdint>
+
 const QString AudioOutputDialog::name = QLatin1String("AudioOutputWidget");
 const QString AudioInputDialog::name  = QLatin1String("AudioInputWidget");
 
@@ -83,7 +86,6 @@ AudioInputDialog::AudioInputDialog(Settings &st) : ConfigWidget(st) {
 
 	qcbDevice->view()->setTextElideMode(Qt::ElideRight);
 
-	on_qcbPushClick_clicked(Global::get().s.bTxAudioCue);
 	on_qcbMuteCue_clicked(Global::get().s.bTxMuteCue);
 	on_Tick_timeout();
 	on_qcbIdleAction_currentIndexChanged(Global::get().s.iaeIdleAction);
@@ -129,13 +131,15 @@ void AudioInputDialog::load(const Settings &r) {
 	qlePushClickPathOn->setText(r.qsTxAudioCueOn);
 	qlePushClickPathOff->setText(r.qsTxAudioCueOff);
 	qleMuteCuePath->setText(r.qsTxMuteCue);
+	s.muteCueShown = r.muteCueShown;
+
 
 	loadComboBox(qcbTransmit, r.atTransmit);
 	loadSlider(qsTransmitHold, r.iVoiceHold);
-	loadSlider(qsTransmitMin, iroundf(r.fVADmin * 32767.0f + 0.5f));
-	loadSlider(qsTransmitMax, iroundf(r.fVADmax * 32767.0f + 0.5f));
+	loadSlider(qsTransmitMin, static_cast< int >(r.fVADmin * 32767.0f + 0.5f));
+	loadSlider(qsTransmitMax, static_cast< int >(r.fVADmax * 32767.0f + 0.5f));
 	loadSlider(qsFrames, (r.iFramesPerPacket == 1) ? 1 : (r.iFramesPerPacket / 2 + 1));
-	loadSlider(qsDoublePush, iroundf(static_cast< float >(r.uiDoublePush) / 1000.f + 0.5f));
+	loadSlider(qsDoublePush, static_cast< int >(static_cast< float >(r.uiDoublePush) / 1000.f + 0.5f));
 	loadSlider(qsPTTHold, static_cast< int >(r.pttHold));
 
 	if (r.vsVAD == Settings::Amplitude)
@@ -144,7 +148,9 @@ void AudioInputDialog::load(const Settings &r) {
 		qrbSNR->setChecked(true);
 
 	loadCheckBox(qcbPushWindow, r.bShowPTTButtonWindow);
-	loadCheckBox(qcbPushClick, r.bTxAudioCue);
+	loadCheckBox(qcbEnableCuePTT, r.audioCueEnabledPTT);
+	loadCheckBox(qcbEnableCueVAD, r.audioCueEnabledVAD);
+	updateAudioCueEnabled();
 	loadCheckBox(qcbMuteCue, r.bTxMuteCue);
 	loadSlider(qsQuality, r.iQuality);
 	loadCheckBox(qcbAllowLowDelay, r.bAllowLowDelay);
@@ -202,7 +208,7 @@ void AudioInputDialog::load(const Settings &r) {
 	loadSlider(qsAmp, 20000 - r.iMinLoudness);
 
 	// Idle auto actions
-	qsbIdle->setValue(r.iIdleTime / 60);
+	qsbIdle->setValue(static_cast< int >(r.iIdleTime) / 60);
 	loadComboBox(qcbIdleAction, r.iaeIdleAction);
 	loadCheckBox(qcbUndoIdleAction, r.bUndoIdleActionUponActivity);
 
@@ -257,17 +263,18 @@ void AudioInputDialog::save() const {
 	s.vsVAD            = qrbSNR->isChecked() ? Settings::SignalToNoise : Settings::Amplitude;
 	s.iFramesPerPacket = qsFrames->value();
 	s.iFramesPerPacket = (s.iFramesPerPacket == 1) ? 1 : ((s.iFramesPerPacket - 1) * 2);
-	s.uiDoublePush     = qsDoublePush->value() * 1000;
-	s.pttHold          = qsPTTHold->value();
+	s.uiDoublePush     = static_cast< unsigned int >(qsDoublePush->value() * 1000);
+	s.pttHold          = static_cast< quint64 >(qsPTTHold->value());
 	s.atTransmit       = static_cast< Settings::AudioTransmit >(qcbTransmit->currentIndex());
 
 	// Idle auto actions
-	s.iIdleTime                   = qsbIdle->value() * 60;
+	s.iIdleTime                   = static_cast< unsigned int >(qsbIdle->value() * 60);
 	s.iaeIdleAction               = static_cast< Settings::IdleAction >(qcbIdleAction->currentIndex());
 	s.bUndoIdleActionUponActivity = qcbUndoIdleAction->isChecked();
 
 	s.bShowPTTButtonWindow = qcbPushWindow->isChecked();
-	s.bTxAudioCue          = qcbPushClick->isChecked();
+	s.audioCueEnabledPTT   = qcbEnableCuePTT->isChecked();
+	s.audioCueEnabledVAD   = qcbEnableCueVAD->isChecked();
 	s.qsTxAudioCueOn       = qlePushClickPathOn->text();
 	s.qsTxAudioCueOff      = qlePushClickPathOff->text();
 
@@ -383,15 +390,25 @@ void AudioInputDialog::updateBitrate() {
 	qsQuality->setMinimum(8000);
 }
 
-void AudioInputDialog::on_qcbPushClick_clicked(bool b) {
-	qpbPushClickBrowseOn->setEnabled(b);
-	qpbPushClickBrowseOff->setEnabled(b);
-	qpbPushClickPreview->setEnabled(b);
-	qpbPushClickReset->setEnabled(b);
-	qlePushClickPathOn->setEnabled(b);
-	qlePushClickPathOff->setEnabled(b);
-	qlPushClickOn->setEnabled(b);
-	qlPushClickOff->setEnabled(b);
+void AudioInputDialog::on_qcbEnableCuePTT_clicked() {
+	updateAudioCueEnabled();
+}
+
+void AudioInputDialog::on_qcbEnableCueVAD_clicked() {
+	updateAudioCueEnabled();
+}
+
+void AudioInputDialog::updateAudioCueEnabled() {
+	bool enabled = qcbEnableCuePTT->isChecked() || qcbEnableCueVAD->isChecked();
+
+	qpbPushClickBrowseOn->setEnabled(enabled);
+	qpbPushClickBrowseOff->setEnabled(enabled);
+	qpbPushClickPreview->setEnabled(enabled);
+	qpbPushClickReset->setEnabled(enabled);
+	qlePushClickPathOn->setEnabled(enabled);
+	qlePushClickPathOff->setEnabled(enabled);
+	qlPushClickOn->setEnabled(enabled);
+	qlPushClickOff->setEnabled(enabled);
 }
 
 void AudioInputDialog::on_qpbPushClickBrowseOn_clicked() {
@@ -411,11 +428,14 @@ void AudioInputDialog::on_qpbPushClickBrowseOff_clicked() {
 void AudioInputDialog::on_qpbPushClickPreview_clicked() {
 	AudioOutputPtr ao = Global::get().ao;
 	if (ao) {
-		AudioOutputSample *sample = ao->playSample(qlePushClickPathOn->text(), Global::get().s.cueVolume);
-		if (sample)
-			connect(sample, SIGNAL(playbackFinished()), this, SLOT(continuePlayback()));
-		else // If we fail to playback the first play on play at least off
+		AudioOutputToken sample = ao->playSample(qlePushClickPathOn->text(), Global::get().s.cueVolume);
+		if (sample) {
+			sample.connect< AudioOutputSample >(&AudioOutputSample::playbackFinished, *this,
+												&AudioInputDialog::continuePlayback);
+		} else {
+			// If we fail to playback the first play on play at least off
 			ao->playSample(qlePushClickPathOff->text(), Global::get().s.cueVolume);
+		}
 	}
 }
 
@@ -423,6 +443,7 @@ void AudioInputDialog::on_qcbMuteCue_clicked(bool b) {
 	qleMuteCuePath->setEnabled(b);
 	qpbMuteCueBrowse->setEnabled(b);
 	qpbMuteCuePreview->setEnabled(b);
+	s.muteCueShown = true;
 }
 
 void AudioInputDialog::on_qpbMuteCueBrowse_clicked() {
@@ -435,8 +456,9 @@ void AudioInputDialog::on_qpbMuteCueBrowse_clicked() {
 
 void AudioInputDialog::on_qpbMuteCuePreview_clicked() {
 	AudioOutputPtr ao = Global::get().ao;
-	if (ao)
+	if (ao) {
 		ao->playSample(qleMuteCuePath->text(), Global::get().s.cueVolume);
+	}
 }
 
 void AudioInputDialog::continuePlayback() {
@@ -517,14 +539,14 @@ void AudioInputDialog::updateEchoEnableState() {
 	qcbEcho->setItemData(0, tr("Disable echo cancellation."), Qt::ToolTipRole);
 
 	int i = 0;
-	for (EchoCancelOptionID ecoid : air->echoOptions) {
-		if (air->canEcho(ecoid, outputInterface)) {
+	for (EchoCancelOptionID echoid : air->echoOptions) {
+		if (air->canEcho(echoid, outputInterface)) {
 			++i;
 			hasUsableEchoOption                = true;
-			const EchoCancelOption &echoOption = EchoCancelOption::getOptions()[static_cast< int >(ecoid)];
-			qcbEcho->insertItem(i, echoOption.description, static_cast< int >(ecoid));
+			const EchoCancelOption &echoOption = EchoCancelOption::getOptions()[static_cast< std::size_t >(echoid)];
+			qcbEcho->insertItem(i, echoOption.description, static_cast< int >(echoid));
 			qcbEcho->setItemData(i, echoOption.explanation, Qt::ToolTipRole);
-			if (s.echoOption == ecoid) {
+			if (s.echoOption == echoid) {
 				qcbEcho->setCurrentIndex(i);
 			}
 		}
@@ -558,9 +580,9 @@ void AudioInputDialog::on_Tick_timeout() {
 	abSpeech->iAbove = qsTransmitMax->value();
 
 	if (qrbAmplitude->isChecked()) {
-		abSpeech->iValue = iroundf((32767.f / 96.0f) * (96.0f + ai->dPeakCleanMic) + 0.5f);
+		abSpeech->iValue = static_cast< int >((32767.f / 96.0f) * (96.0f + ai->dPeakCleanMic) + 0.5f);
 	} else {
-		abSpeech->iValue = iroundf(ai->fSpeechProb * 32767.0f + 0.5f);
+		abSpeech->iValue = static_cast< int >(ai->fSpeechProb * 32767.0f + 0.5f);
 	}
 	abSpeech->update();
 }
@@ -627,11 +649,11 @@ AudioOutputDialog::AudioOutputDialog(Settings &st) : ConfigWidget(st) {
 	// Distance in cm
 	qsMinDistance->setRange(0, 200);
 	// Distance in m
-	qsbMinimumDistance->setRange(0.0, 50.0);
+	qsbMinimumDistance->setRange(0.0, 1000.0);
 	// Distance in cm
 	qsMaxDistance->setRange(10, 2000);
 	// Distance in m
-	qsbMaximumDistance->setRange(1.0, 1000.0);
+	qsbMaximumDistance->setRange(1.0, 10000.0);
 	qsMinimumVolume->setRange(0, 100);
 	qsbMinimumVolume->setRange(qsMinimumVolume->minimum(), qsMinimumVolume->maximum());
 	qsBloom->setRange(0, 75);
@@ -693,8 +715,8 @@ void AudioOutputDialog::load(const Settings &r) {
 
 	loadCheckBox(qcbExclusive, r.bExclusiveOutput);
 	loadSlider(qsDelay, r.iOutputDelay);
-	loadSlider(qsVolume, iroundf(r.fVolume * 100.0f + 0.5f));
-	loadSlider(qsOtherVolume, iroundf((1.0f - r.fOtherVolume) * 100.0f + 0.5f));
+	loadSlider(qsVolume, static_cast< int >(r.fVolume * 100.0f + 0.5f));
+	loadSlider(qsOtherVolume, static_cast< int >((1.0f - r.fOtherVolume) * 100.0f + 0.5f));
 	loadCheckBox(qcbAttenuateOthersOnTalk, r.bAttenuateOthersOnTalk);
 	loadCheckBox(qcbAttenuateOthers, r.bAttenuateOthers);
 	loadCheckBox(qcbAttenuateUsersOnPrioritySpeak, r.bAttenuateUsersOnPrioritySpeak);
@@ -710,11 +732,11 @@ void AudioOutputDialog::load(const Settings &r) {
 	loadSlider(qsJitter, r.iJitterBufferSize);
 	loadComboBox(qcbLoopback, r.lmLoopMode);
 	loadSlider(qsPacketDelay, static_cast< int >(r.dMaxPacketDelay));
-	loadSlider(qsPacketLoss, iroundf(r.dPacketLoss * 100.0f + 0.5f));
+	loadSlider(qsPacketLoss, static_cast< int >(r.dPacketLoss * 100.0f + 0.5f));
 	qsbMinimumDistance->setValue(r.fAudioMinDistance);
 	qsbMaximumDistance->setValue(r.fAudioMaxDistance);
-	qsbMinimumVolume->setValue(r.fAudioMaxDistVolume * 100);
-	qsbBloom->setValue(r.fAudioBloom * 100);
+	qsbMinimumVolume->setValue(static_cast< int >(r.fAudioMaxDistVolume * 100));
+	qsbBloom->setValue(static_cast< int >(r.fAudioBloom * 100));
 	loadCheckBox(qcbHeadphones, r.bPositionalHeadphone);
 	loadCheckBox(qcbPositional, r.bPositionalAudio);
 
@@ -838,21 +860,33 @@ void AudioOutputDialog::on_qcbLoopback_currentIndexChanged(int v) {
 
 void AudioOutputDialog::on_qsMinDistance_valueChanged(int value) {
 	QSignalBlocker blocker(qsbMinimumDistance);
-	qsbMinimumDistance->setValue(value / 10.0f);
+	qsbMinimumDistance->setValue(value / 10.0);
+
+	// Ensure that max distance is always a least 1m larger than min distance
+	qsbMaximumDistance->setValue(std::max(qsbMaximumDistance->value(), (value / 10.0) + 1));
 }
 
 void AudioOutputDialog::on_qsbMinimumDistance_valueChanged(double value) {
 	QSignalBlocker blocker(qsMinDistance);
-	qsMinDistance->setValue(value * 10);
+	qsMinDistance->setValue(static_cast< int >(value * 10));
+
+	// Ensure that max distance is always a least 1m larger than min distance
+	qsMaxDistance->setValue(std::max(qsMaxDistance->value(), static_cast< int >(value * 10) + 10));
 }
 
 void AudioOutputDialog::on_qsMaxDistance_valueChanged(int value) {
 	QSignalBlocker blocker(qsbMaximumDistance);
-	qsbMaximumDistance->setValue(value / 10.0f);
+	qsbMaximumDistance->setValue(value / 10.0);
+
+	// Ensure that min distance is always a least 1m less than max distance
+	qsbMinimumDistance->setValue(std::min(qsbMinimumDistance->value(), (value / 10.0) - 1));
 }
 void AudioOutputDialog::on_qsbMaximumDistance_valueChanged(double value) {
 	QSignalBlocker blocker(qsMaxDistance);
-	qsMaxDistance->setValue(value * 10);
+	qsMaxDistance->setValue(static_cast< int >(value * 10));
+
+	// Ensure that min distance is always a least 1m less than max distance
+	qsMinDistance->setValue(std::min(qsMinDistance->value(), static_cast< int >(value * 10) - 10));
 }
 
 void AudioOutputDialog::on_qsMinimumVolume_valueChanged(int value) {
