@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -213,7 +213,8 @@ bool AudioInputRegistrar::isMicrophoneAccessDeniedByOS() {
 	return false;
 }
 
-AudioInput::AudioInput() : opusBuffer(Global::get().s.iFramesPerPacket * (SAMPLE_RATE / 100)) {
+AudioInput::AudioInput()
+	: opusBuffer(static_cast< std::size_t >(Global::get().s.iFramesPerPacket * (SAMPLE_RATE / 100))) {
 	bDebugDumpInput         = Global::get().bDebugDumpInput;
 	resync.bDebugPrintQueue = Global::get().bDebugPrintQueue;
 	if (bDebugDumpInput) {
@@ -286,6 +287,7 @@ AudioInput::AudioInput() : opusBuffer(Global::get().s.iFramesPerPacket * (SAMPLE
 
 	connect(this, SIGNAL(doDeaf()), Global::get().mw->qaAudioDeaf, SLOT(trigger()), Qt::QueuedConnection);
 	connect(this, SIGNAL(doMute()), Global::get().mw->qaAudioMute, SLOT(trigger()), Qt::QueuedConnection);
+	connect(this, SIGNAL(doMuteCue()), Global::get().mw, SLOT(on_muteCuePopup_triggered()));
 }
 
 AudioInput::~AudioInput() {
@@ -318,7 +320,7 @@ AudioInput::~AudioInput() {
 
 bool AudioInput::isTransmitting() const {
 	return bPreviousVoice;
-};
+}
 
 #define IN_MIXER_FLOAT(channels)                                                                             \
 	static void inMixerFloat##channels(float *RESTRICT buffer, const void *RESTRICT ipt, unsigned int nsamp, \
@@ -355,7 +357,8 @@ static void inMixerFloatMask(float *RESTRICT buffer, const void *RESTRICT ipt, u
 	const float *RESTRICT input = reinterpret_cast< const float * >(ipt);
 
 	unsigned int chancount = 0;
-	STACKVAR(unsigned int, chanindex, N);
+	static std::vector< unsigned int > chanindex;
+	chanindex.resize(N);
 	for (unsigned int j = 0; j < N; ++j) {
 		if ((mask & (1ULL << j)) == 0) {
 			continue;
@@ -379,7 +382,8 @@ static void inMixerShortMask(float *RESTRICT buffer, const void *RESTRICT ipt, u
 	const short *RESTRICT input = reinterpret_cast< const short * >(ipt);
 
 	unsigned int chancount = 0;
-	STACKVAR(unsigned int, chanindex, N);
+	static std::vector< unsigned int > chanindex;
+	chanindex.resize(N);
 	for (unsigned int j = 0; j < N; ++j) {
 		if ((mask & (1ULL << j)) == 0) {
 			continue;
@@ -535,9 +539,10 @@ void AudioInput::initializeMixer() {
 	imfMic  = chooseMixer(iMicChannels, eMicFormat, uiMicChannelMask);
 	imfEcho = chooseMixer(iEchoChannels, eEchoFormat, uiEchoChannelMask);
 
-	iMicSampleSize = static_cast< int >(iMicChannels * ((eMicFormat == SampleFloat) ? sizeof(float) : sizeof(short)));
+	iMicSampleSize =
+		static_cast< unsigned int >(iMicChannels * ((eMicFormat == SampleFloat) ? sizeof(float) : sizeof(short)));
 	iEchoSampleSize =
-		static_cast< int >(iEchoChannels * ((eEchoFormat == SampleFloat) ? sizeof(float) : sizeof(short)));
+		static_cast< unsigned int >(iEchoChannels * ((eEchoFormat == SampleFloat) ? sizeof(float) : sizeof(short)));
 
 	bResetProcessor = true;
 
@@ -652,7 +657,7 @@ void AudioInput::addEcho(const void *data, unsigned int nsamp) {
 
 			// float -> 16bit PCM
 			const float mul = 32768.f;
-			for (int j = 0; j < iEchoFrameSize; ++j) {
+			for (unsigned int j = 0; j < iEchoFrameSize; ++j) {
 				outbuff[j] = static_cast< short >(qBound(-32768.f, (ptr[j] * mul), 32767.f));
 			}
 
@@ -761,7 +766,7 @@ void AudioInput::resetAudioProcessor() {
 	speex_preprocess_ctl(sppPreprocess, SPEEX_PREPROCESS_SET_AGC_TARGET, &iArg);
 
 	float v = 30000.0f / static_cast< float >(Global::get().s.iMinLoudness);
-	iArg    = iroundf(floorf(20.0f * log10f(v)));
+	iArg    = static_cast< int >(floorf(20.0f * log10f(v)));
 	speex_preprocess_ctl(sppPreprocess, SPEEX_PREPROCESS_SET_AGC_MAX_GAIN, &iArg);
 
 	iArg = -60;
@@ -774,8 +779,9 @@ void AudioInput::resetAudioProcessor() {
 
 	if (iEchoChannels > 0) {
 		int filterSize = iFrameSize * (10 + resync.getNominalLag());
-		sesEcho        = speex_echo_state_init_mc(iFrameSize, filterSize, 1, bEchoMulti ? iEchoChannels : 1);
-		iArg           = iSampleRate;
+		sesEcho =
+			speex_echo_state_init_mc(iFrameSize, filterSize, 1, bEchoMulti ? static_cast< int >(iEchoChannels) : 1);
+		iArg = iSampleRate;
 		speex_echo_ctl(sesEcho, SPEEX_ECHO_SET_SAMPLING_RATE, &iArg);
 		speex_preprocess_ctl(sppPreprocess, SPEEX_PREPROCESS_SET_ECHO_STATE, sesEcho);
 
@@ -858,7 +864,6 @@ int AudioInput::encodeOpusFrame(short *source, int size, EncodingOutputBuffer &b
 
 void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 	int iArg;
-	int i;
 	float sum;
 	short max;
 
@@ -871,14 +876,14 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 	// if the value of Global::get().iTarget changes during the execution of this function,
 	// it won't cause any inconsistencies and the change is reflected once this
 	// function is called again.
-	int voiceTargetID = Global::get().iTarget;
+	std::int32_t voiceTargetID = Global::get().iTarget;
 
 	if (!bRunning)
 		return;
 
 	sum = 1.0f;
 	max = 1;
-	for (i = 0; i < iFrameSize; i++) {
+	for (unsigned int i = 0; i < iFrameSize; i++) {
 		sum += static_cast< float >(chunk.mic[i] * chunk.mic[i]);
 		max = std::max(static_cast< short >(abs(chunk.mic[i])), max);
 	}
@@ -887,7 +892,7 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 
 	if (chunk.speaker && (iEchoChannels > 0)) {
 		sum = 1.0f;
-		for (i = 0; i < iEchoFrameSize; ++i) {
+		for (unsigned int i = 0; i < iEchoFrameSize; ++i) {
 			sum += static_cast< float >(chunk.speaker[i] * chunk.speaker[i]);
 		}
 		dPeakSpeaker = qMax(20.0f * log10f(sqrtf(sum / static_cast< float >(iFrameSize)) / 32768.0f), -96.0f);
@@ -917,13 +922,13 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 	// At the time of writing this code, RNNoise only supports a sample rate of 48000 Hz.
 	if (noiseCancel == Settings::NoiseCancelRNN || noiseCancel == Settings::NoiseCancelBoth) {
 		float denoiseFrames[480];
-		for (int i = 0; i < 480; i++) {
+		for (unsigned int i = 0; i < 480; i++) {
 			denoiseFrames[i] = psSource[i];
 		}
 
 		rnnoise_process_frame(denoiseState, denoiseFrames, denoiseFrames);
 
-		for (int i = 0; i < 480; i++) {
+		for (unsigned int i = 0; i < 480; i++) {
 			psSource[i] = clampFloatSample(denoiseFrames[i]);
 		}
 	}
@@ -932,7 +937,7 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 	speex_preprocess_run(sppPreprocess, psSource);
 
 	sum = 1.0f;
-	for (i = 0; i < iFrameSize; i++)
+	for (unsigned int i = 0; i < iFrameSize; i++)
 		sum += static_cast< float >(psSource[i] * psSource[i]);
 	float micLevel = sqrtf(sum / static_cast< float >(iFrameSize));
 	dPeakSignal    = qMax(20.0f * log10f(micLevel / 32768.0f), -96.0f);
@@ -940,9 +945,11 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 	if (bDebugDumpInput) {
 		outMic.write(reinterpret_cast< const char * >(chunk.mic), iFrameSize * sizeof(short));
 		if (chunk.speaker) {
-			outSpeaker.write(reinterpret_cast< const char * >(chunk.speaker), iEchoFrameSize * sizeof(short));
+			outSpeaker.write(reinterpret_cast< const char * >(chunk.speaker),
+							 static_cast< std::streamsize >(iEchoFrameSize * sizeof(short)));
 		}
-		outProcessed.write(reinterpret_cast< const char * >(psSource), iFrameSize * sizeof(short));
+		outProcessed.write(reinterpret_cast< const char * >(psSource),
+						   static_cast< std::streamsize >(iFrameSize * sizeof(short)));
 	}
 
 	spx_int32_t prob = 0;
@@ -972,20 +979,26 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 		iHoldFrames = 0;
 	}
 
+	// If Global::get().iPushToTalk > 0 that means that we are currently in some sort of PTT action. For
+	// instance this could mean we're currently whispering
+	bool isPTT = Global::get().iPushToTalk > 0;
+
 	if (Global::get().s.atTransmit == Settings::Continuous
 		|| API::PluginData::get().overwriteMicrophoneActivation.load()) {
 		// Continuous transmission is enabled
 		bIsSpeech = true;
 	} else if (Global::get().s.atTransmit == Settings::PushToTalk) {
 		// PTT is enabled, so check if it is currently active
-		bIsSpeech = Global::get().s.uiDoublePush
-					&& ((Global::get().uiDoublePush < Global::get().s.uiDoublePush)
-						|| (Global::get().tDoublePush.elapsed() < Global::get().s.uiDoublePush));
+		bool doublePush = Global::get().s.uiDoublePush > 0
+						  && ((Global::get().uiDoublePush < Global::get().s.uiDoublePush)
+							  || (Global::get().tDoublePush.elapsed() < Global::get().s.uiDoublePush));
+
+		// With double push enabled, we might be in a PTT state without pressing any PTT key
+		isPTT     = isPTT || doublePush;
+		bIsSpeech = isPTT;
 	}
 
-	// If Global::get().iPushToTalk > 0 that means that we are currently in some sort of PTT action. For
-	// instance this could mean we're currently whispering
-	bIsSpeech = bIsSpeech || (Global::get().iPushToTalk > 0);
+	bIsSpeech = bIsSpeech || isPTT;
 
 	ClientUser *p          = ClientUser::get(Global::get().uiSession);
 	bool bTalkingWhenMuted = false;
@@ -1006,22 +1019,35 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 	if (p) {
 		if (!bIsSpeech)
 			p->setTalking(Settings::Passive);
-		else if (voiceTargetID == 0)
+		else if (voiceTargetID == Mumble::Protocol::ReservedTargetIDs::REGULAR_SPEECH)
 			p->setTalking(Settings::Talking);
 		else
 			p->setTalking(Settings::Shouting);
 	}
 
-	if (Global::get().uiSession != 0 && (Global::get().s.bTxAudioCue || Global::get().s.bTxMuteCue)) {
+	if (Global::get().uiSession != 0) {
 		AudioOutputPtr ao = Global::get().ao;
 
 		if (ao) {
-			if (Global::get().s.bTxAudioCue) {
-				if (bIsSpeech && !bPreviousVoice) {
-					ao->playSample(Global::get().s.qsTxAudioCueOn, Global::get().s.cueVolume);
-				} else if (!bIsSpeech && bPreviousVoice) {
-					ao->playSample(Global::get().s.qsTxAudioCueOff, Global::get().s.cueVolume);
-				}
+			const bool treatAsPTT         = isPTT || previousPTT;
+			const bool audioCueEnabledPTT = Global::get().s.audioCueEnabledPTT && treatAsPTT;
+			const bool audioCueEnabledVAD =
+				Global::get().s.audioCueEnabledVAD && Global::get().s.atTransmit == Settings::VAD && !treatAsPTT;
+			const bool audioCueEnabled = audioCueEnabledPTT || audioCueEnabledVAD;
+
+			const bool playAudioOnCue  = bIsSpeech && !bPreviousVoice && audioCueEnabled;
+			const bool playAudioOffCue = !bIsSpeech && bPreviousVoice && audioCueEnabled;
+			const bool stopActiveCue   = m_activeAudioCue && (playAudioOnCue || playAudioOffCue);
+
+			if (stopActiveCue) {
+				// Cancel active cue first, if there is any
+				ao->removeToken(m_activeAudioCue);
+			}
+
+			if (playAudioOnCue) {
+				m_activeAudioCue = ao->playSample(Global::get().s.qsTxAudioCueOn, Global::get().s.cueVolume);
+			} else if (playAudioOffCue) {
+				m_activeAudioCue = ao->playSample(Global::get().s.qsTxAudioCueOff, Global::get().s.cueVolume);
 			}
 
 			if (Global::get().s.bTxMuteCue && !Global::get().bPushToMute && !Global::get().s.bDeaf
@@ -1029,6 +1055,7 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 				if (!qetLastMuteCue.isValid() || qetLastMuteCue.elapsed() > MUTE_CUE_DELAY) {
 					qetLastMuteCue.start();
 					ao->playSample(Global::get().s.qsTxMuteCue, Global::get().s.cueVolume);
+					emit doMuteCue();
 				}
 			}
 		}
@@ -1097,7 +1124,7 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 			// a codec configuration switch by suddenly using a wildly different
 			// framecount per packet.
 			const int missingFrames = iAudioFrames - iBufferedFrames;
-			opusBuffer.insert(opusBuffer.end(), iFrameSize * missingFrames, 0);
+			opusBuffer.insert(opusBuffer.end(), static_cast< std::size_t >(iFrameSize * missingFrames), 0);
 			iBufferedFrames += missingFrames;
 			iFrameCounter += missingFrames;
 		}
@@ -1123,23 +1150,24 @@ void AudioInput::encodeAudioFrame(AudioChunk chunk) {
 		iBitrate = 0;
 
 	bPreviousVoice = bIsSpeech;
+	previousPTT    = isPTT;
 }
 
 static void sendAudioFrame(gsl::span< const Mumble::Protocol::byte > encodedPacket) {
 	ServerHandlerPtr sh = Global::get().sh;
 	if (sh) {
-		sh->sendMessage(encodedPacket.data(), encodedPacket.size());
+		sh->sendMessage(encodedPacket.data(), static_cast< int >(encodedPacket.size()));
 	}
 }
 
-void AudioInput::flushCheck(const QByteArray &frame, bool terminator, int voiceTargetID) {
+void AudioInput::flushCheck(const QByteArray &frame, bool terminator, std::int32_t voiceTargetID) {
 	qlFrames << frame;
 
 	if (!terminator && iBufferedFrames < iAudioFrames)
 		return;
 
 	Mumble::Protocol::AudioData audioData;
-	audioData.targetOrContext = voiceTargetID;
+	audioData.targetOrContext = static_cast< std::uint32_t >(voiceTargetID);
 	audioData.isLastFrame     = terminator;
 
 	if (terminator && Global::get().iPrevTarget > 0) {
@@ -1149,7 +1177,7 @@ void AudioInput::flushCheck(const QByteArray &frame, bool terminator, int voiceT
 		// is reset to 0 by now. In order to send the last whisper frame correctly, we have to use
 		// Global::get().iPrevTarget which is set to whatever Global::get().iTarget has been before its last change.
 
-		audioData.targetOrContext = Global::get().iPrevTarget;
+		audioData.targetOrContext = static_cast< std::uint32_t >(Global::get().iPrevTarget);
 
 		// We reset Global::get().iPrevTarget as it has fulfilled its purpose for this whisper-action. It'll be set
 		// accordingly once the client whispers for the next time.
@@ -1164,7 +1192,7 @@ void AudioInput::flushCheck(const QByteArray &frame, bool terminator, int voiceT
 	int frames      = iBufferedFrames;
 	iBufferedFrames = 0;
 
-	audioData.frameNumber = iFrameCounter - frames;
+	audioData.frameNumber = static_cast< std::size_t >(iFrameCounter - frames);
 
 	if (Global::get().s.bTransmitPosition && Global::get().pluginManager && !Global::get().bCenterPosition
 		&& Global::get().pluginManager->fetchPositionalData()) {
@@ -1182,7 +1210,8 @@ void AudioInput::flushCheck(const QByteArray &frame, bool terminator, int voiceT
 	assert(qlFrames.size() == 1);
 
 	audioData.payload = gsl::span< const Mumble::Protocol::byte >(
-		reinterpret_cast< const Mumble::Protocol::byte * >(qlFrames[0].constData()), qlFrames[0].size());
+		reinterpret_cast< const Mumble::Protocol::byte * >(qlFrames[0].constData()),
+		static_cast< std::size_t >(qlFrames[0].size()));
 
 	{
 		ServerHandlerPtr sh = Global::get().sh;
