@@ -1,4 +1,4 @@
-// Copyright 2007-2022 The Mumble Developers. All rights reserved.
+// Copyright 2007-2023 The Mumble Developers. All rights reserved.
 // Use of this source code is governed by a BSD-style license
 // that can be found in the LICENSE file at the root of the
 // Mumble source tree or at <https://www.mumble.info/LICENSE>.
@@ -13,6 +13,7 @@
 #include <boost/array.hpp>
 #include <boost/shared_ptr.hpp>
 
+#include <cstdint>
 #include <fstream>
 #include <list>
 #include <memory>
@@ -24,6 +25,7 @@
 #include <speex/speex_resampler.h>
 
 #include "Audio.h"
+#include "AudioOutputToken.h"
 #include "EchoCancelOption.h"
 #include "MumbleProtocol.h"
 #include "Settings.h"
@@ -197,6 +199,8 @@ private:
 
 	QElapsedTimer qetLastMuteCue;
 
+	AudioOutputToken m_activeAudioCue;
+
 protected:
 	Mumble::Protocol::AudioCodec m_codec;
 	SampleFormat eMicFormat, eEchoFormat;
@@ -205,7 +209,7 @@ protected:
 	unsigned int iMicFreq, iEchoFreq;
 	unsigned int iMicLength, iEchoLength;
 	unsigned int iMicSampleSize, iEchoSampleSize;
-	int iEchoMCLength, iEchoFrameSize;
+	unsigned int iEchoMCLength, iEchoFrameSize;
 	quint64 uiMicChannelMask, uiEchoChannelMask;
 
 	bool bEchoMulti;
@@ -247,6 +251,7 @@ protected:
 
 	volatile bool bRunning;
 	volatile bool bPreviousVoice;
+	volatile bool previousPTT;
 
 	int iFrameCounter;
 	int iSilentFrames;
@@ -254,7 +259,7 @@ protected:
 	int iBufferedFrames;
 
 	QList< QByteArray > qlFrames;
-	void flushCheck(const QByteArray &, bool terminator, int voiceTargetID);
+	void flushCheck(const QByteArray &, bool terminator, std::int32_t voiceTargetID);
 
 	void initializeMixer();
 
@@ -262,6 +267,7 @@ protected:
 signals:
 	void doDeaf();
 	void doMute();
+	void doMuteCue();
 	/// A signal emitted if audio input is being encountered
 	///
 	/// @param inputPCM The encountered input PCM
